#
# spec file for package plantuml
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plantuml
Version:        1.2023.1
Release:        1.4
Summary:        Java UML Tool
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Other
URL:            http://plantuml.com/
Source0:        http://downloads.sourceforge.net/plantuml/%{name}-lgpl-%{version}.tar.gz
Source1:        %{name}.script
Source10:       http://pdf.plantuml.net/PlantUML_Language_Reference_Guide_en.pdf
Patch0:         build-with-javac-utf8-encoding.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  xmvn-install
Requires:       java >= 1.8.0
Requires:       javapackages-tools
BuildArch:      noarch

%description
PlantUML is a program allowing to draw UML diagrams, using a simple
and human readable text description. It is extremely useful for code
documenting, sketching project architecture during team conversations
and so on.

PlantUML supports the following diagram types
  - sequence diagram
  - use case diagram
  - class diagram
  - activity diagram
  - component diagram
  - state diagram

%package javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/Other

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -c -n plantuml
%patch0 -p1
cp %{SOURCE1} %{name}
cp %{SOURCE10} .
# only contains a single line pointing to website
rm README

%build
ant

# build javadoc
export CLASSPATH=$(build-classpath ant):plantuml.jar
%javadoc -source 1.8 -encoding UTF-8 -Xdoclint:none -d javadoc $(find src -name "*.java") -windowtitle "PlantUML %{version}"

%install
# Set jar location
%mvn_file net.sourceforge.%{name}:%{name} %{name}
# Configure maven depmap
%mvn_artifact net.sourceforge.%{name}:%{name}:%{version} %{name}.jar
%mvn_install -J javadoc

install -m 755 -d %{buildroot}%{_bindir}/
install -m 755 -d %{buildroot}%{_javadir}
install -m 755 %{name} %{buildroot}%{_bindir}/%{name}

# Install jar file
cp %{name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

%fdupes %{buildroot}%{_datadir}

%files -f .mfiles
%{_bindir}/plantuml
%{_javadir}/%{name}-%{version}.jar
%license COPYING

%files javadoc -f .mfiles-javadoc
%license COPYING

%changelog
* Sun Jan 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.1
  See http://plantuml.com/de/changes for all changes
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.0
  See http://plantuml.com/de/changes for all changes
* Fri Dec 16 2022 Michael Ströder <michael@stroeder.com>
- Update to version 1.2022.14
  See http://plantuml.com/de/changes for all changes
* Sun Sep 18 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2022.7
  See http://plantuml.com/de/changes for all changes
* Mon May 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.5
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1379 (bsc#1199557)
- Update patch
  * build-with-javac-utf8-encoding.patch
* Tue Apr 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.4
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1231 (bsc#1198591)
* Wed Mar 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.3
  See http://plantuml.com/de/changes for all changes
* Wed Jan 12 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.0
  See http://plantuml.com/de/changes for all changes
* Mon Nov  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.13
  See http://plantuml.com/de/changes for all changes
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.12
  See http://plantuml.com/de/changes for all changes
* Thu Sep 16 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2021.10
  See http://plantuml.com/de/changes for all changes
- Add patch:
  * build-with-javac-utf8-encoding.patch
* Sun Apr  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.4
  See http://plantuml.com/de/changes for all changes
* Tue Mar 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.3
  See http://plantuml.com/de/changes for all changes
- Drop patch:
  * remove-non-ascii-char.patch (fixed upstream)
* Fri Mar  5 2021 Markus Ebner <info@ebner-markus.de>
- Cleanup
- Update to version 1.2021.1
  See http://plantuml.com/de/changes for all changes
- Build plantuml-javadoc package
- Add patch:
  * remove-non-ascii-char.patch
* Tue Oct 20 2020 Pedro Monreal <pmonreal@suse.com>
- Update link to the pdf manual in the plantuml.xml file
* Mon Oct 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.19
  See http://plantuml.com/de/changes for all changes
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.18
  See http://plantuml.com/de/changes for all changes
* Sun Sep 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.17
  See http://plantuml.com/de/changes for all changes
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.15
  See http://plantuml.com/de/changes for all changes
* Wed Jun 17 2020 Fridrich Strba <fstrba@suse.com>
- Documentation fix: [bsc#1169765]
  * Fetch the PlantUML_Language_Reference_Guide_en.pdf instead of
    a web page that wraps the PDF in javascript feeding ads.
* Wed Jun 17 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to version 1.2020.13
  See http://plantuml.com/de/changes for all changes
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.12
  See http://plantuml.com/de/changes for all changes
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.9
  See http://plantuml.com/de/changes for all changes
* Tue Apr 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.8
  See http://plantuml.com/de/changes for all changes
* Mon Apr  6 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- Added requirement 'dejavu-fonts'
* Sun Apr  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.6
  See http://plantuml.com/de/changes for all changes
* Wed Dec 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.13
  See http://plantuml.com/de/changes for all changes
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.12
  See http://plantuml.com/de/changes for all changes
* Sun Sep 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.11
  See http://plantuml.com/de/changes for all changes
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.10
  See http://plantuml.com/de/changes for all changes
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.9
  See http://plantuml.com/de/changes for all changes
* Mon May 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.6
  See http://plantuml.com/de/changes for all changes
* Mon Apr 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream version 1.2019.4
- Restore original changelog entries
* Fri Feb  8 2019 ahasenkopf@suse.com
- Fixed package internal issues
* Fri Jan 11 2019 ahasenkopf@suse.com
- First commit for version 1.2018.14
* Tue Sep  4 2018 mardnh@gmx.de
- Update to new upstream version 1.2018.10
- Run spec-cleander
* Tue Aug 25 2015 michiel.vanderwulp@gmail.com
- Improve the man page
* Thu Aug 20 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8029
* Fri Jun  5 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8025
* Sun Sep  4 2011 toms@suse.de
- Initial version 7177
